@@ -259,6 +259,8 @@ from ncbi.datasets.openapi.model.v1reports_genomic_region_genomic_region_type im
 from ncbi.datasets.openapi.model.v1reports_genomic_region_genomic_region_type import V1reportsGenomicRegionGenomicRegionType as V1alpha1reportsGenomicRegionGenomicRegionType
 from ncbi.datasets.openapi.model.v1reports_lineage_organism import V1reportsLineageOrganism
 from ncbi.datasets.openapi.model.v1reports_lineage_organism import V1reportsLineageOrganism as V1alpha1reportsLineageOrganism
+from ncbi.datasets.openapi.model.v1reports_linked_assembly_linked_assembly_type import V1reportsLinkedAssemblyLinkedAssemblyType
+from ncbi.datasets.openapi.model.v1reports_linked_assembly_linked_assembly_type import V1reportsLinkedAssemblyLinkedAssemblyType as V1alpha1reportsLinkedAssemblyLinkedAssemblyType
 from ncbi.datasets.openapi.model.v1reports_organism import V1reportsOrganism
 from ncbi.datasets.openapi.model.v1reports_organism import V1reportsOrganism as V1alpha1reportsOrganism
 from ncbi.datasets.openapi.model.v1reports_orientation import V1reportsOrientation
